@@ -393,44 +393,91 @@ class Customer(object):
                             }
         # defup aiguiller v2
         if bool_defup:
-            res = requests.delete('{}={}&periode={}'.format(
-                URL_V2,
-                self.name,
-                period
-                ),
-                auth=(
-                    CONFIG['AIGUILLIER']['username'],
-                    CONFIG['AIGUILLIER']['password']
-                    )
-                )
-            if res.status_code == 200:
-                res = res.json()
-                if res['status'] == '200':
-                    LOGS.logger.info(
-                        "[DEFUP] Customer {} removed from DT database"
-                        .format(self.name)
-                    )
-                else:
-                    LOGS.logger.error(
-                        "[DEFUP] Unable to remove customer {} from DT database"
-                        .format(self.name)
-                    )
-            else:
-                LOGS.logger.error(
-                    "[DEFUP] Unable to remove customer {} from DT database"
-                    .format(self.name)
-                )
-
+            self.defup_aiguiller(self.name, period)
         if bool_delete and bool_defup:
+            self.defup_si(self.name, "gp")
+        return result
+
+    def defup_si(self, name, customer_type):
+        """
+        Removes customer from SI database.
+        :param name: customer or product name
+        :param customer_type: ["gp", "ese"]
+        """
+        try:
+            if customer_type not in ["gp", "ese"]:
+                raise ValueError("Unknown customer type")
+
             url = core.database_url(**FUPDB_CREDENTIALS)
             with records.Database(url) as db:
-                sql = "DELETE FROM customer WHERE name=:name"
-                db.query(sql, name=self.name)
+                if customer_type == "gp":
+                    sql = "DELETE FROM customer WHERE name=:name"
+                    db.query(sql, name=str(name))
+                    LOGS.logger.info(
+                        "Customer '{}'({}) deleted from SI database"
+                        .format(name, customer_type)
+                    )
+                elif customer_type == "ese":
+                    sql = "DELETE FROM customer_ese WHERE product=:product"
+                    db.query(sql, product=str(name))
+                    LOGS.logger.info(
+                        "Customer with product '{}'({}) deleted "
+                        "from SI database"
+                        .format(name, customer_type)
+                    )
+        except Exception as e:
+            LOGS.logger.error(
+                "Unable to DEFUP customer {}({}) from SI: {}"
+                .format(name, customer_type, str(e))
+            )
+            core.send_error_report(
+                "DEFUP customer {}({}) from SI database"
+                .format(name, customer_type),
+                str(e)
+            )
+
+    def defup_aiguiller(self, customer_name, period):
+        """
+        Removes customer from DT database via Aiguiller.
+        Operation is attempted 3 times.
+        """
+        defuped = False
+        for attempt in range(1, 3):
+            try:
+                response = requests.delete(
+                    URL_V2 + '/consommation?remettre_normal={}&periode={}'
+                    .format(self.name, period),
+                    auth=(
+                        CONFIG['AIGUILLIER']['username'],
+                        CONFIG['AIGUILLIER']['password']
+                    )
+                )
+                if (
+                        response.status_code == 200
+                        and response.json()['status'] == '200'
+                ):
+                    defuped = True
+                    break
+            except Exception as e:
+                LOGS.logger.warning(
+                    "[DEFUP] Try {} out of 3. "
+                    "Unable to remove customer {} from DT database: {} "
+                    .format(attempt, customer_name, str(e))
+                )
+        if defuped:
             LOGS.logger.info(
-                "[DEFUP] Customer {} removed from SI FUP database"
-                .format(self.name)
+                "[DEFUP] Customer {} removed from DT database"
+                .format(customer_name)
+            )
+        else:
+            LOGS.logger.error(
+                "[DEFUP] Unable to remove customer {} from DT database"
+                .format(customer_name)
+            )
+            core.send_error_report(
+                "DEFUP customer {} from Aiguillier".format(customer_name),
+                "cf. /var/log/fup-services/fup-services.log"
             )
-        return result
 
     def get_cdr_from_aiguillier(self, last_date):
         """Récupération des CDRs a une date donné
